postal_address package
======================

Subpackages
-----------

.. toctree::

    postal_address.tests

Submodules
----------

postal_address.address module
-----------------------------

.. automodule:: postal_address.address
    :members:
    :undoc-members:
    :show-inheritance:

postal_address.territory module
-------------------------------

.. automodule:: postal_address.territory
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: postal_address
    :members:
    :undoc-members:
    :show-inheritance:
